merlin.core.photonicbackend module (removed)
===========================================

.. warning:: *Deprecated since version 0.3:*
    This module name is no longer used.

    See :mod:`merlin.core.merlin_processor`.
